@@ -1,7 +1,9 @@
 """Define the MyQ API."""
 import asyncio
-from datetime import datetime, timedelta
 import logging
+import string
+from datetime import datetime, timedelta
+from random import choices
 from typing import Dict, Optional
 
 from aiohttp import ClientSession
@@ -17,7 +19,9 @@ BASE_API_VERSION = 5
 API_BASE = "https://api.myqdevice.com/api/v{0}"
 
 DEFAULT_APP_ID = "JVM/G9Nwih5BwKgNCjLxiFUQxQijAebyyg8QUHr7JOrP+tuPb8iHfRHKwTmDzHOu"
-DEFAULT_USER_AGENT = "okhttp/3.10.0"
+# Generate random string for User Agent.
+# DEFAULT_USER_AGENT = "".join(choices(string.ascii_letters + string.digits, k=10))
+DEFAULT_USER_AGENT = "pymyq"
 DEFAULT_BRAND_ID = 2
 DEFAULT_REQUEST_RETRIES = 5
 DEFAULT_CULTURE = "en"
@@ -91,8 +95,11 @@ class API:  # pylint: disable=too-many-instance-attributes
                     resp.raise_for_status()
                     return data
             except ClientError as err:
-                _LOGGER.debug(f"Attempt {attempt} request failed with exception: {str(err)}")
-                if hasattr(err, "status") and err.status == 401:
+                _LOGGER.debug(f"Attempt {attempt} request failed with exception:: {str(err)}")
+                status_code = err.status if hasattr(err, "status") else ""
+
+                message = f"Error requesting data from {url}: {str(status_code)} - {data.get('description', str(err))}"
+                if status_code == 401:
                     if login_request:
                         self._credentials = {}
                         raise InvalidCredentialsError("Invalid username/password")
@@ -111,7 +118,6 @@ class API:  # pylint: disable=too-many-instance-attributes
                     attempt = 0
                     continue
 
-        message = f"Error requesting data from {url}: {data.get('description', str(err))}"
         _LOGGER.error(message)
         raise RequestError(message)
 
@@ -253,8 +259,9 @@ class API:  # pylint: disable=too-many-instance-attributes
         self._last_state_update = datetime.utcnow()
 
 
-async def login(username: str, password: str, websession: ClientSession = None) -> API:
+async def login(username: str, password: str, websession: ClientSession = None, useragent: str = DEFAULT_USER_AGENT) -> API:
     """Log in to the API."""
+    MYQ_HEADERS.update({"User-Agent": useragent})
     api = API(websession)
     await api.authenticate(username, password, False)
     return api
